@@ -239,12 +239,14 @@ class Repository(_Base):
                 self._push_time = time.time()
 
     def sync(self):
-        """If enabled, perform an automatic pull an push.
+        """If enabled, perform an automatic pull and push.
         """
         if self._auto_pull:
-            self.pull()
+            self._pull_time = 0
+            self.pull(_auto=True)
         if self._auto_push:
-            self.push()
+            self._push_time = 0
+            self.push(_auto=True)
 
     @property
     @auto_pull
