@@ -5,6 +5,7 @@ Unit tests for the veracity package.
 """
 
 import os
+from random import randrange
 import logging
 from pprint import pformat
 
@@ -17,7 +18,7 @@ TEST = os.path.dirname(os.path.abspath(__file__))
 FILES = os.path.join(TEST, 'files')
 
 TEST_REPO_NAME = 'python-veracity-test'  # repository for integration tests
-TEMP_REPO_NAME = TEST_REPO_NAME + '-temp'  # temporary repository for clones
+TEMP_REPO_NAME = TEST_REPO_NAME + '-temp' + str(randrange(999))
 REASON = "no test repository available"
 if settings.CREATE_TEST_REPO and TEST_REPO_NAME not in vv.repos():
     common.create_test_repo(TEST_REPO_NAME)
