@@ -59,6 +59,12 @@ class TestRun(unittest.TestCase):
         """Verify a builder step can be run in test mode."""
         self.assertTrue(run(Config(path=os.path.join(FILES, 'builder.cfg'), repos=[self.repo.name]), test='U'))
 
+    def test_run_valid_request_delete(self):
+        """Verify an invalid build request gets deleted."""
+        del self.repo.builds
+        self.repo.request_build('test', 'C', 'W', 'Q', 1, branch='master')
+        self.assertTrue(run(Config(repos=[self.repo.name], envs=['W'])))
+
     def test_run_invalid(self):
         """Verify a poller returns an error with no repository."""
         self.assertFalse(run(Config()))
